@@ -124,3 +124,14 @@ class DockerImages(ImagesGateway):
                 f"Compliance issue: the source base image date ({date.strftime('%Y-%m-%d')}) is older than the referenced date ({reference_date.strftime('%Y-%m-%d')})."
             )
         return True
+
+    def validate_black_list_base_image(self, base_image, black_list):
+        if not isinstance(base_image, str) or not isinstance(black_list, list):
+            logger.error("Invalid input types: expected a string and a list of strings.")
+            return False
+        for black in black_list:
+            if black in base_image:
+                raise ValueError(
+                f"Compliance issue: the image: {base_image} is blacklisted for {black}"
+            )
+        return True
\ No newline at end of file
